## Product details

Introducing New & Improved WaterWipes, the World’s Purest Wipes for Sensitive Skin. Families can continue to trust WaterWipes Sensitive+ New Born & Baby Wipes to gently clean, care and help protect sensitive skin - now with a 2X stronger. Thicker and softer wipe, and a fresh new look. Our plant-based & plastic free wipes maintain the same purity, with just two carefully selected ingredients: 99.9% ultra-purified water and a drop of fruit extract. Our ultra-purified water undergoes a 7-step process, making it even purer than tap, boiled, or bottled water. WaterWipes remain unscented, hypoallergenic, and gentle on sensitive skin. They are clinically proven to be kind to baby’s skin—giving parents the confidence to help protect their children in the purest way possible. WaterWipes was born from a father's love—our founder created these wipes after his newborn suffered from diaper rash, realizing that skin this pure deserves care that’s just as pure. That inspiration led to the creation of the world’s purest wipes for sensitive skin, trusted by families worldwide for everything from diaper changes to messy hands and faces. material than previous WaterWipes Claim does not refer to the full product lifecycle nor packaging. Wipes made from regenerated cellulose.
MADE WITH BABY IN MIND: Crafted to gently clean and help protect premature, infant and newborn skin, these Sensitive+ Newborn & Baby Wipes have just two ingredients - 99.9% purified water and a drop of fruit extract.
EVERYDAY USE ON SENSITIVE SKIN: When life plays dirty, WaterWipes plays it clean. Ideal for cleaning small messes and refreshing skin on-the-go, these disposable wipes make the perfect daily essential.
3-IN-1 SKIN CARE BENEFITS: Made using minimal ingredients, our wipes have a neutral pH range, which helps protect the natural skin barrier.
2X STRONGER: Upgraded for more versatility, WaterWipes are now thicker, softer & 2x stronger to tackle tougher messes while keeping the same, trusted purity.
PURE & GENTLE FORMULA: WaterWipes unique 7 stage water purification, requires minimum ingredients, with 0% fragrance and alcohol.
PLASTIC-FREE*, PLANT BASED WIPES: Suitable for eczema-prone skin and allergy sufferers, WaterWipes are Dermatologically Approved by the Skin Health Alliance, accepted by the National Eczema Association of America and registered by the Vegan Society.
DERMATOLOGIST TESTED FOR SENSITIVE SKIN: WaterWipes baby wipes are dermatologist tested and suitable for delicate and eczema-prone skin. Their gentle formula helps cleanse effectively while caring for skin that needs extra softness.
EVERYDAY CARE WITH GENTLE INGREDIENTS: Made with 99.9% purified water and a drop of fruit extract, WaterWipes baby wipes are ideal for daily messes. Their neutral pH makes them ideal for refreshing sensitive skin.
*Claim does not refer to the full product lifecycle nor packaging. Wipes made from regenerated cellulose.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Primary ingredient
Water
Ingredient properties
Hypoallergenic
Scent
Unscented
Features
Resealable
More details
## Directions

Instructions
A few tips: Because we don't use chemicals to "bind" the liquid to the wipes like other brands, the water can sometimes migrate to the bottom of the pack, making the top wipes feel a bit dry. To remedy this, simply turn the closed pack over and squeeze it a few times and that will redistribute the water throughout the wipes.

## Ingredients
Aqua, Citrus Grandis Seed Extract**Contains trace of Benzalkonium Chloride

Active Ingredient Name
Aqua, Citrus Grandis Seed Extract*, *Contains Trace of Benzalkonium Chloride.
